# Lavalink.py

- if using on linux, run lavalink.jar with sudo
- Note to self: VC Disconnects after connecting are caused by websockets<4.0        *fml*

[Head here for instructions on getting lavalink.py configured](https://github.com/Devoxin/Lavalink.py/wiki)

[Get Support](https://discord.gg/SbJXU9s)
